@@ -3,12 +3,14 @@
 
 These are necessary to avoid circular imports between core.py and fields.py.
 '''
+import copy
 
 
 class FieldABC(object):
     '''Abstract base class from which all Field classes inherit.
     '''
     parent = None
+    name = None
 
     def format(self, value):
         raise NotImplementedError
@@ -16,6 +18,10 @@ class FieldABC(object):
     def output(self, key, obj):
         raise NotImplementedError
 
+    def __deepcopy__(self, memo):
+        ret = copy.copy(self)
+        return ret
+
     def __repr__(self):
         return "<{0} Field>".format(self.__class__.__name__)
 
