@@ -18,14 +18,25 @@ from marshmallow.exceptions import MarshallingError
 
 def validated(f):
     """Decorator that wraps a field's ``format`` or ``output`` method. If an
-    exception is raised during the execution of the wrapped method, a
+    exception is raised during the execution of the wrapped method or the
+    field object's ``validate`` function evaluates to ``False``, a
     MarshallingError is raised instead with the underlying exception's
     error message or the user-defined error message (if defined).
     """
     @wraps(f)
     def decorated(self, *args, **kwargs):
         try:
-            return f(self, *args, **kwargs)
+            output = f(self, *args, **kwargs)
+            if hasattr(self, 'validate') and callable(self.validate):
+                if not self.validate(output):
+                    msg = 'Validator {0}({1}) is not True'.format(
+                        self.validate.__name__, output
+                    )
+                    raise MarshallingError(getattr(self, "error", None) or msg)
+            return output
+        # TypeErrors should be raised if fields are not declared as instances
+        except TypeError:
+            raise
         except Exception as error:
             raise MarshallingError(getattr(self, "error", None) or error)
     return decorated
@@ -83,7 +94,7 @@ class Marshaller(object):
     # Make an instance callable
     __call__ = marshal
 
-# Singleton marshaller method for use in this module
+# Singleton marshaller function for use in this module
 marshal = Marshaller(strict=True)
 
 
@@ -124,12 +135,16 @@ class Raw(FieldABC):
     :param str attribute: The name of the attribute to get the value from. If
         ``None``, assumes the attribute has the same name as the field.
     :param str error: Error message stored upon validation failure.
+    :param callable validate: Validation function that takes the output as its
+        only paramter and returns a boolean. If it returns False, a
+        MarshallingError is raised.
     """
 
-    def __init__(self, default=None, attribute=None, error=None):
+    def __init__(self, default=None, attribute=None, error=None, validate=None):
         self.attribute = attribute
         self.default = default
         self.error = error
+        self.validate = validate
 
     def get_value(self, key, obj):
         '''Return the value for a given key from an object.'''
@@ -150,6 +165,7 @@ class Raw(FieldABC):
         """
         return value
 
+    @validated
     def output(self, key, obj):
         """Pulls the value for the given key from the object, applies the
         field's formatting and returns the result.
@@ -266,6 +282,7 @@ def flatten(dictlist, key):
     """
     return [d[key] for d in dictlist]
 
+
 class List(Raw):
     '''A list field.
 
@@ -307,9 +324,10 @@ class List(Raw):
 class String(Raw):
     """A string field."""
 
-    def __init__(self, default='', attribute=None, *args, **kwargs):
+    def __init__(self, default='', attribute=None,  *args, **kwargs):
         return super(String, self).__init__(default, attribute, *args, **kwargs)
 
+    @validated
     def format(self, value):
         try:
             return text_type(value)
@@ -341,6 +359,7 @@ class Number(Raw):
         else:
             return self.num_type(value)
 
+    @validated
     def format(self, value):
         try:
             if value is None:
@@ -394,9 +413,10 @@ class Arbitrary(Number):
     ex: 634271127864378216478362784632784678324.23432
     """
     # No as_string param
-    def __init__(self, default=0, attribute=None):
-        super(Arbitrary, self).__init__(default=default, attribute=attribute)
+    def __init__(self, default=0, attribute=None, **kwargs):
+        super(Arbitrary, self).__init__(default=default, attribute=attribute, **kwargs)
 
+    @validated
     def format(self, value):
         try:
             if value is None:
@@ -424,8 +444,8 @@ class DateTime(Raw):
     """
     localtime = False
 
-    def __init__(self, format=None, default=None, attribute=None):
-        super(DateTime, self).__init__(default=default, attribute=attribute)
+    def __init__(self, format=None, default=None, attribute=None, **kwargs):
+        super(DateTime, self).__init__(default=default, attribute=attribute, **kwargs)
         self.dateformat = format
 
     @validated
@@ -450,6 +470,7 @@ class LocalDateTime(DateTime):
 class Time(Raw):
     """ISO8601-formatted time string."""
 
+    @validated
     def format(self, value):
         try:
             ret = value.isoformat()
@@ -464,6 +485,7 @@ class Time(Raw):
 class Date(Raw):
     """ISO8601-formatted date string."""
 
+    @validated
     def format(self, value):
         try:
             return value.isoformat()
@@ -478,6 +500,7 @@ class TimeDelta(Raw):
     as a float.
     '''
 
+    @validated
     def format(self, value):
         try:
             return total_seconds(value)
@@ -554,10 +577,11 @@ class Method(Raw):
         (in addition to self) that is the object to be serialized.
     """
 
-    def __init__(self, method_name):
+    def __init__(self, method_name, **kwargs):
         self.method_name = method_name
-        super(Method, self).__init__()
+        super(Method, self).__init__(**kwargs)
 
+    @validated
     def output(self, key, obj):
         try:
             return getattr(self.parent, self.method_name)(obj)
@@ -573,15 +597,17 @@ class Function(Raw):
         to be serialized.
     '''
 
-    def __init__(self, func):
+    def __init__(self, func, **kwargs):
+        super(Function, self).__init__(**kwargs)
         self.func = func
 
+    @validated
     def output(self, key, obj):
         try:
             return self.func(obj)
         except TypeError as te:  # Function is not callable
             raise MarshallingError(te)
-        except AttributeError:
+        except AttributeError:  # the object is not expected to have the attribute
             pass
 
 
@@ -594,9 +620,9 @@ class Select(Raw):
         ``None``, assumes the attribute has the same name as the field.
     :param str error: Error message stored upon validation failure.
     """
-    def __init__(self,  choices, default=None, attribute=None, error=None):
+    def __init__(self,  choices, default=None, attribute=None, error=None, **kwargs):
         self.choices = choices
-        return super(Select, self).__init__(default, attribute, error)
+        return super(Select, self).__init__(default, attribute, error, **kwargs)
 
     def format(self, value):
         if value not in self.choices:
